@@ -1,8 +1,8 @@
 /*
  * Copyright (c) 2000 Mark B. Allan. All rights reserved.
  *
- * "Chromium B.S.U." is free software; you can redistribute 
- * it and/or use it and/or modify it under the terms of the 
+ * "Chromium B.S.U." is free software; you can redistribute
+ * it and/or use it and/or modify it under the terms of the
  * "Clarified Artistic License"
  */
 
@@ -23,19 +23,19 @@
 #include <cmath>
 using namespace std;
 
-#if !defined(USE_SDL) && defined(SDL_CD_STUBS)
+#if !defined(USE_SDL_CDROM) && defined(SDL_CD_STUBS)
 void	SDL_CDPlayTracks(void*, int, int, int, int) {}
 void	SDL_CDPause(void*)	{}
 void	SDL_CDResume(void*)	{}
 void	SDL_CDStop(void*)	{}
 int		SDL_CDStatus(void*)	{ return 0; }
-#endif //USE_SDL
+#endif //USE_SDL_CDROM
 
 //====================================================================
 Audio::Audio()
 {
 	Config	*config = Config::instance();
-	
+
     fileNames[HeroAmmo00]	= "wav/boom.wav";
 	fileNames[PowerUp]		= "wav/power.wav";
 	fileNames[Explosion]	= "wav/exploStd.wav";
@@ -45,23 +45,29 @@ Audio::Audio()
 	fileNames[AddLife]		= "wav/life_add.wav";
 	fileNames[MusicGame]	= "wav/music_game.wav";
 	fileNames[MusicMenu]	= "wav/music_menu.wav";
-	
+
+#ifdef USE_SDL_CDROM
 	cdrom = NULL;
+#endif // USE_SDL_CDROM
 	musicMax = 1;
 	musicIndex = 0;
-	
+
 	if(config->audioEnabled() == true)
 	{
+#ifdef USE_SDL_CDROM
 		initCDROM();
+#endif // USE_SDL_CDROM
 	}
 }
 
 Audio::~Audio()
 {
+#ifdef USE_SDL_CDROM
 	if(cdrom)
 	{
 		SDL_CDStop(cdrom);
 	}
+#endif // USE_SDL_CDROM
 }
 
 /**
@@ -96,12 +102,7 @@ void	Audio::initSound()
  * if GLUT is being used.
  */
 //----------------------------------------------------------
-#ifndef USE_SDL
-void	Audio::initCDROM()
-{
-	cdrom = 0;
-}
-#else // USE_SDL
+#ifdef USE_SDL_CDROM
 static const char *trackType(int t)
 {
 	static char buf[64];
@@ -137,14 +138,14 @@ void Audio::initCDROM()
 					for(int i = 0; i < cdrom->numtracks; i++)
 					{
 						if( config->debug() ) fprintf(stderr, _("track %2d: %s\n"), i, trackType(cdrom->track[i].type));
-						// SDL BUG? 'type' should only be SDL_DATA_TRACK(0x04)or SDL_AUDIO_TRACK(0x00), but 
+						// SDL BUG? 'type' should only be SDL_DATA_TRACK(0x04)or SDL_AUDIO_TRACK(0x00), but
 						// this is returning SDL_AUDIO_TRACK=0x02 and SDL_DATA_TRACK=0x06 on some copied CDRs!
-						// Orignal CDs return correct values, but CDR duplications are off by 2!
+						// Original CDs return correct values, but CDR duplications are off by 2!
 						if(cdrom->track[i].type < SDL_DATA_TRACK)
 							music++;
 					}
 					if(!music)
-					{		
+					{
 						if( config->debug() ) fprintf(stderr, _("\n Data track(s) only. CD audio not available.\n\n"));
 						SDL_CDStop(cdrom);
 						cdrom = 0;
@@ -153,7 +154,7 @@ void Audio::initCDROM()
 					{
 						fprintf(stderr, _("\n use_cdrom enabled. Set to '0' in the configuration file to disable.\n"));
 						fprintf(stderr, _(" Press the \'N\' key to skip to next CD track during a game.\n\n"));
-					}	
+					}
 				}
 				else
 				{
@@ -165,14 +166,14 @@ void Audio::initCDROM()
 			{
 				if( config->debug() ) fprintf(stderr, _("ERROR! Could not access CDROM device %d : %s\n"), config->CDROMDevice(), SDL_GetError());
 				SDL_ClearError();
-				config->setCDROMDevice(0); 
+				config->setCDROMDevice(0);
 			}
 		}
 	}
 	else
 		cdrom = 0;
 }
-#endif // USE_SDL
+#endif // USE_SDL_CDROM
 
 /**
  * stop CD track
@@ -183,8 +184,10 @@ void	Audio::stopMusic()
 	Config	*config = Config::instance();
 	if(config->audioEnabled() == true)
 	{
+#ifdef USE_SDL_CDROM
 		if(cdrom)
 			SDL_CDStop(cdrom);
+#endif // USE_SDL_CDROM
 	}
 }
 
@@ -197,6 +200,7 @@ void	Audio::pauseGameMusic(bool status)
 	Config	*config = Config::instance();
 	if(config->audioEnabled() == true)
 	{
+#ifdef USE_SDL_CDROM
 		if(cdrom)
 		{
 			int cdromStatus = SDL_CDStatus(cdrom);
@@ -210,15 +214,17 @@ void	Audio::pauseGameMusic(bool status)
 				fprintf(stderr, _("CDROM status = %d\n"), cdromStatus);
 			}
 		}
+#endif // USE_SDL_CDROM
 	}
 }
 
-/** 
+/**
  * switch between menu and game music modes
  */
 //----------------------------------------------------------
 void	Audio::setMusicMode(SoundType mode)
 {
+#ifdef USE_SDL_CDROM
 	Global	*game = Global::getInstance();
 	Config	*config = Config::instance();
 	if(config->audioEnabled() == true)
@@ -247,6 +253,7 @@ void	Audio::setMusicMode(SoundType mode)
 			}
 		}
 	}
+#endif // USE_SDL_CDROM
 }
 
 /**
@@ -256,6 +263,7 @@ void	Audio::setMusicMode(SoundType mode)
 void	Audio::setMusicVolume(float value)
 {
 #ifdef __linux__
+#ifdef USE_SDL_CDROM
 	Config	*config = Config::instance();
 	if (config->audioEnabled() && config->useCDROM())
 	{
@@ -275,6 +283,7 @@ void	Audio::setMusicVolume(float value)
 			fprintf(stderr, _("Could not set CD volume, amixer returned status %d\n"), status);
 		}
 	}
+#endif // USE_SDL_CDROM
 #endif // __linux__
 }
 
@@ -296,13 +305,14 @@ void	Audio::setMusicIndex(int index)
 	Config	*config = Config::instance();
 	if(config->audioEnabled() == true)
 	{
-		bool	wasPlaying = false;
 		if(musicMax)
 			musicIndex = index%musicMax;
 		if( config->debug() ) fprintf(stderr, _("Audio::setMusicIndex(%d)\n"), musicIndex);
-		
+
+#ifdef USE_SDL_CDROM
 		if(cdrom)
 		{
+			bool wasPlaying = false;
 			int cdromStatus = SDL_CDStatus(cdrom);
 			if(cdromStatus == CD_PLAYING)
 				wasPlaying = true;
@@ -320,6 +330,7 @@ void	Audio::setMusicIndex(int index)
 				Audio::setMusicIndex(musicIndex+1);
 			}
 		}
+#endif // USE_SDL_CDROM
 	}
 #endif
 }
