@@ -1,8 +1,8 @@
 /*
  * Copyright (c) 2000 Mark B. Allan. All rights reserved.
  *
- * "Chromium B.S.U." is free software; you can redistribute 
- * it and/or use it and/or modify it under the terms of the 
+ * "Chromium B.S.U." is free software; you can redistribute
+ * it and/or use it and/or modify it under the terms of the
  * "Clarified Artistic License"
  */
 #ifndef Audio_h
@@ -20,25 +20,12 @@
 class SoundInfo;
 class Global;
 
-#ifdef USE_SDL
+#ifdef USE_SDL_CDROM
 #include <SDL.h> // for CDROM
-#else
-#define SDL_CD void
 #endif
 
-#if !defined(USE_SDL) && !defined(SDL_CD_STUBS)
-	#define SDL_CD_STUBS
-	enum { CD_ERROR = -1, CD_TRAYEMPTY, CD_STOPPED, CD_PLAYING, CD_PAUSED };
-	void	SDL_CDPlayTracks(void*, int, int, int, int);
-	void	SDL_CDPause(void*);
-	void	SDL_CDResume(void*);
-	void	SDL_CDStop(void*);
-	int		SDL_CDStatus(void*);
-#endif //USE_SDL
-
-
 /**
- * Base class upon which all audio calls are made. If USE_SDL is defined, 
+ * Base class upon which all audio calls are made. If USE_SDL_CDROM is defined,
  * this class will do CD music playback, but does not do any sound effects.
  */
 //====================================================================
@@ -46,22 +33,22 @@ class Audio
 {
 public:
 	/** available sound effects types */
-	enum SoundType	{	
-						HeroAmmo00, 	/**< unused */			
-						PowerUp,		/**< power up sound */ 	
-						Explosion,		/**< standard explosion */ 
-						ExploPop,		/**< 'light' explosion */ 
+	enum SoundType	{
+						HeroAmmo00, 	/**< unused */
+						PowerUp,		/**< power up sound */
+						Explosion,		/**< standard explosion */
+						ExploPop,		/**< 'light' explosion */
 						ExploBig,		/**< deep, long explosion */
-						AddLife,		/**< new ship earned */  
-						LoseLife,		/**< ship lost */		
-						MusicGame,		/**< gameplay music */ 	
-						MusicMenu, 		/**< menu music */ 		
+						AddLife,		/**< new ship earned */
+						LoseLife,		/**< ship lost */
+						MusicGame,		/**< gameplay music */
+						MusicMenu, 		/**< menu music */
 						NumSoundTypes 	/**< total number of sounds available */
 					};
-	
+
 	Audio();
 	virtual ~Audio();
-	
+
 	virtual void	update();
 	virtual void	playSound(SoundType type, float *pos, int age = 0);
 	virtual void	stopMusic();
@@ -71,13 +58,17 @@ public:
 	virtual void	setSoundVolume(float);
 	virtual void	setMusicIndex(int);
 	virtual void	nextMusicIndex();
-	
+
 protected:
 	virtual void	initSound();
+#ifdef USE_SDL_CDROM
 	virtual void	initCDROM();
+#endif // USE_SDL_CDROM
 
 	const char	*fileNames[NumSoundTypes];	/**< base filenames for sound effects */
+#ifdef USE_SDL_CDROM
 	SDL_CD	*cdrom; 					/**< pointer to CDROM struct. Is void* if not using SDL */
+#endif // USE_SDL_CDROM
 	char	musicFile[MAX_MUSIC][256];	/**< array of filenames for playlist */
 	int		musicMax;					/**< max number of user-defined songs (CD or playlist) */
 	int		musicIndex; 				/**< current track ( 0 < musicIndex < musicMax ) */
@@ -86,18 +77,18 @@ protected:
 
 /**
  * node class used for 'audio queue'
- */ 
+ */
 //======================================
 class SoundInfo
 {
 public:
 	SoundInfo();
 	SoundInfo(Audio::SoundType t, float p[3], int a);
-	
+
 	Audio::SoundType	type;
 	float		pos[3];
 	int			age;
-	
+
 	SoundInfo	*next;
 	SoundInfo	*back;
 };
