@@ -1,8 +1,8 @@
 /*
  * Copyright (c) 2000 Mark B. Allan. All rights reserved.
  *
- * "Chromium B.S.U." is free software; you can redistribute 
- * it and/or use it and/or modify it under the terms of the 
+ * "Chromium B.S.U." is free software; you can redistribute
+ * it and/or use it and/or modify it under the terms of the
  * "Clarified Artistic License"
  */
 
@@ -19,6 +19,7 @@
 #include <cstdlib>
 #include <cstdio>
 #include <cstring>
+#include <cmath>
 
 #include "Config.h"
 
@@ -28,6 +29,18 @@
 #include "Audio.h"
 #include "Ground.h"
 
+#if SDL_VERSION_ATLEAST(2,0,0)
+		#define SDLK_KP1 SDLK_KP_1
+		#define SDLK_KP2 SDLK_KP_2
+		#define SDLK_KP3 SDLK_KP_3
+		#define SDLK_KP4 SDLK_KP_4
+		#define SDLK_KP5 SDLK_KP_5
+		#define SDLK_KP6 SDLK_KP_6
+		#define SDLK_KP7 SDLK_KP_7
+		#define SDLK_KP8 SDLK_KP_8
+		#define SDLK_KP9 SDLK_KP_9
+#endif
+
 //----------------------------------------------------------
 bool MainSDL::process(SDL_Event *event)
 {
@@ -35,7 +48,7 @@ bool MainSDL::process(SDL_Event *event)
 #if 0
 	static int cnt = 0;
 	cnt++;
-	switch( event->type ) 
+	switch( event->type )
 	{
 	    case SDL_ACTIVEEVENT:		fprintf(stderr, _("%-5d SDL_ACTIVEEVENT  \n")		, cnt); break;
 	    case SDL_KEYDOWN:			fprintf(stderr, _("%-5d SDL_KEYDOWN  \n")			, cnt); break;
@@ -49,11 +62,30 @@ bool MainSDL::process(SDL_Event *event)
 			break;
 	}
 #endif
-	switch(event->type) 
+	bool shown, mouse, input, gain = false;
+	switch(event->type)
 	{
+#if SDL_VERSION_ATLEAST(2,0,0)
+	    case SDL_WINDOWEVENT:
+		switch (event->window.event) {
+			case SDL_WINDOWEVENT_RESTORED: shown = true; gain = true; break;
+			case SDL_WINDOWEVENT_MINIMIZED: shown = true; gain = false; break;
+			case SDL_WINDOWEVENT_ENTER: mouse = true; gain = true; break;
+			case SDL_WINDOWEVENT_LEAVE: mouse = true; gain = false; break;
+			case SDL_WINDOWEVENT_FOCUS_GAINED: input = true; gain = true; break;
+			case SDL_WINDOWEVENT_FOCUS_LOST: input = true; gain = false; break;
+		}
+		activation(shown, mouse, input, gain);
+		break;
+#else
 	    case SDL_ACTIVEEVENT:
-			activation(event);
+			shown = event->active.state & SDL_APPACTIVE ? true : false;
+			mouse = event->active.state & SDL_APPMOUSEFOCUS ? true : false;
+			input = event->active.state & SDL_APPINPUTFOCUS ? true : false;
+			gain = event->active.gain ? true : false;
+			activation(shown, mouse, input, gain);
 			break;
+#endif
 	    case SDL_KEYDOWN:
 			keyDown(event);
 			break;
@@ -92,11 +124,15 @@ void MainSDL::saveEvent(SDL_Event *event)
 	Global	*game = Global::getInstance();
 	if(game->eventFile && game->gameMode == Global::Game)
 	{
+#if SDL_VERSION_ATLEAST(2,0,0)
+		SDL_WindowEvent 		*evW = 0;
+#else
 		SDL_ActiveEvent 		*evA = 0;
+#endif
 		SDL_KeyboardEvent 		*evK = 0;
 		SDL_MouseMotionEvent 	*evM = 0;
 		SDL_MouseButtonEvent 	*evB = 0;
-		switch(event->type) 
+		switch(event->type)
 		{
 //	    	case SDL_ACTIVEEVENT:
 //				evA = (SDL_ActiveEvent*)event;
@@ -107,7 +143,7 @@ void MainSDL::saveEvent(SDL_Event *event)
 //	    	case SDL_KEYUP:
 //				evK = (SDL_KeyboardEvent*)event;
 //				fprintf(game->eventFile, "%9d :%s: %5d %5d %5d %5d %5d %5d\n", game->gameFrame, "K",
-//					(int)evK->type, (int)evK->state, 
+//					(int)evK->type, (int)evK->state,
 //					(int)evK->keysym.scancode, (int)evK->keysym.sym, (int)evK->keysym.mod, (int)evK->keysym.unicode);
 //				break;
 //	    	case SDL_MOUSEMOTION:
@@ -123,6 +159,20 @@ void MainSDL::saveEvent(SDL_Event *event)
 //				break;
 //			default:
 //				break;
+#if SDL_VERSION_ATLEAST(2,0,0)
+		case SDL_WINDOWEVENT:
+				evW = (SDL_WindowEvent*)event;
+				fprintf(game->eventFile, "%9d :%s: %5d %5d %5d %5d %5d %5d\n", game->gameFrame, "W",
+					evW->type, evW->windowID, evW->event, evW->data1, evW->data2, 0);
+				break;
+	    	case SDL_KEYDOWN:
+	    	case SDL_KEYUP:
+				evK = (SDL_KeyboardEvent*)event;
+				fprintf(game->eventFile, "%9d :%s: %5d %5d %5d %5d %5d\n", game->gameFrame, "K",
+					evK->type, evK->state,
+					evK->keysym.scancode, evK->keysym.sym, evK->keysym.mod);
+				break;
+#else
 	    	case SDL_ACTIVEEVENT:
 				evA = (SDL_ActiveEvent*)event;
 				fprintf(game->eventFile, "%9d :%s: %5d %5d %5d %5d %5d %5d\n", game->gameFrame, "A",
@@ -132,9 +182,10 @@ void MainSDL::saveEvent(SDL_Event *event)
 	    	case SDL_KEYUP:
 				evK = (SDL_KeyboardEvent*)event;
 				fprintf(game->eventFile, "%9d :%s: %5d %5d %5d %5d %5d %5d\n", game->gameFrame, "K",
-					evK->type, evK->state, 
+					evK->type, evK->state,
 					evK->keysym.scancode, evK->keysym.sym, evK->keysym.mod, evK->keysym.unicode);
 				break;
+#endif
 	    	case SDL_MOUSEMOTION:
 				evM = (SDL_MouseMotionEvent*)event;
 				fprintf(game->eventFile, "%9d :%s: %5d %5d %5d %5d %5d %5d\n", game->gameFrame, "M",
@@ -160,36 +211,57 @@ SDL_Event *MainSDL::getEvent(FILE *infile)
 	static	SDL_Event ev;
 	static	char buffer[256] = { "-1 :K: 2 0 0 0 0 0"};
 	SDL_Event	*retVal = 0;
-	
+
 	if(infile)
 	{
+#if SDL_VERSION_ATLEAST(2,0,0)
+		SDL_WindowEvent 		*evW = (SDL_WindowEvent*)&ev;
+#else
 		SDL_ActiveEvent 		*evA = (SDL_ActiveEvent*)&ev;
+#endif
 		SDL_KeyboardEvent 		*evK = (SDL_KeyboardEvent*)&ev;
 		SDL_MouseMotionEvent 	*evM = (SDL_MouseMotionEvent*)&ev;
 		SDL_MouseButtonEvent 	*evB = (SDL_MouseButtonEvent*)&ev;
 		int		frame;
 		int		a,b,c,d,e,f;
 		char	t;
-		
+
 		sscanf(buffer, "%d :%c: %d %d %d %d %d %d", &frame, &t, &a, &b, &c, &d, &e, &f);
 		if(frame == game->gameFrame)
 		{
 			switch(t)
 			{
+#if SDL_VERSION_ATLEAST(2,0,0)
+				case 'W':
+					evW->type	= (Uint32)a;
+					evW->windowID	= (Uint32)b;
+					evW->event	= (Uint8)c;
+					evW->data1	= d;
+					evW->data2	= e;
+					retVal = &ev;
+					break;
+#else
 				case 'A':
 					evA->type	= (Uint8)a;
 					evA->gain	= (Uint8)b;
 					evA->state	= (Uint8)c;
 					retVal = &ev;
 					break;
+#endif
 				case 'K':
 					evK->type	= (Uint8)a;
 					evK->state	= (Uint8)b;
+#if SDL_VERSION_ATLEAST(2,0,0)
+					evK->keysym.scancode = (SDL_Scancode)c;
+					evK->keysym.sym		 = (SDL_Keycode)d;
+					evK->keysym.mod		 = (SDL_Keymod)e;
+#else
 					evK->keysym.scancode = (Uint8)c;
 					evK->keysym.sym		 = (SDLKey)d;
 					evK->keysym.mod		 = (SDLMod)e;
 					evK->keysym.unicode	 = (Uint16)f;
-					retVal = &ev;	
+#endif
+					retVal = &ev;
 					break;
 				case 'M':
 					evM->type	= (Uint8)a;
@@ -227,28 +299,28 @@ SDL_Event *MainSDL::getEvent(FILE *infile)
 }
 
 //----------------------------------------------------------
-void MainSDL::activation(SDL_Event *event)
+void MainSDL::activation(bool shown, bool mouse, bool input, bool gain)
 {
 	Global *game = Global::getInstance();
 	Config* config = Config::instance();
-	if( config->debug() ) fprintf(stderr, "app %s ", event->active.gain ? "gained" : "lost" );
-	bool grab_mouse = game->gameMode == Global::Game && !game->game_pause && event->active.gain ? true : false;
-	if ( event->active.state & SDL_APPACTIVE ) 
+	if( config->debug() ) fprintf(stderr, "app %s ", gain ? "gained" : "lost" );
+	bool grab_mouse = game->gameMode == Global::Game && !game->game_pause && gain ? true : false;
+	if ( shown )
 	{
 		grabMouse( grab_mouse, grab_mouse );
 		if( config->debug() ) fprintf(stderr, "app active " );
-	} 
-	else if ( event->active.state & SDL_APPMOUSEFOCUS ) 
+	}
+	else if ( mouse )
 	{
-		if( config->debug() ) fprintf(stderr, _("mouse active") );
+		if( config->debug() ) fprintf(stderr, "mouse active" );
 		SDL_GetMouseState(&xLast, &yLast);
-	} 
-	else if ( event->active.state & SDL_APPINPUTFOCUS ) 
+	}
+	else if ( input )
 	{
 		grabMouse( grab_mouse, grab_mouse );
 		if( config->debug() ) fprintf(stderr, "input active" );
 	}
-	if( config->debug() ) fprintf(stderr, _("focus\n") );
+	if( config->debug() ) fprintf(stderr, "focus\n" );
 }
 
 //----------------------------------------------------------
@@ -412,19 +484,45 @@ void MainSDL::keyMove()
 {
 	Global	*game = Global::getInstance();
 	if(game->gameMode == Global::Game){
-#if SDL_MAJOR_VERSION == 1 && SDL_MINOR_VERSION >= 3
-		Uint8 *keystate = SDL_GetKeyboardState(NULL);
+#if SDL_VERSION_ATLEAST(2,0,0)
+		const Uint8 *keystate = SDL_GetKeyboardState(NULL);
+		#define LEFT SDL_SCANCODE_LEFT
+		#define RIGHT SDL_SCANCODE_RIGHT
+		#define UP SDL_SCANCODE_UP
+		#define DOWN SDL_SCANCODE_DOWN
+		#define KP1 SDL_SCANCODE_KP_1
+		#define KP2 SDL_SCANCODE_KP_2
+		#define KP3 SDL_SCANCODE_KP_3
+		#define KP4 SDL_SCANCODE_KP_4
+		#define KP5 SDL_SCANCODE_KP_5
+		#define KP6 SDL_SCANCODE_KP_6
+		#define KP7 SDL_SCANCODE_KP_7
+		#define KP8 SDL_SCANCODE_KP_8
+		#define KP9 SDL_SCANCODE_KP_9
 #else
 		Uint8 *keystate = SDL_GetKeyState(NULL);
+		#define LEFT SDLK_LEFT
+		#define RIGHT SDLK_RIGHT
+		#define UP SDLK_UP
+		#define DOWN SDLK_DOWN
+		#define KP1 SDLK_KP1
+		#define KP2 SDLK_KP2
+		#define KP3 SDLK_KP3
+		#define KP4 SDLK_KP4
+		#define KP5 SDLK_KP5
+		#define KP6 SDLK_KP6
+		#define KP7 SDLK_KP7
+		#define KP8 SDLK_KP8
+		#define KP9 SDLK_KP9
 #endif
-		if( keystate[SDLK_LEFT]  || keystate[SDLK_KP4] ) key_speed_x -= 2.0 + abs(key_speed_x)*0.4;
-		if( keystate[SDLK_RIGHT] || keystate[SDLK_KP6] ) key_speed_x += 2.0 + abs(key_speed_x)*0.4;
-		if( keystate[SDLK_UP]    || keystate[SDLK_KP8] ) key_speed_y -= 2.0 + abs(key_speed_y)*0.4;
-		if( keystate[SDLK_DOWN]  || keystate[SDLK_KP2] ) key_speed_y += 2.0 + abs(key_speed_y)*0.4;
-		if( keystate[SDLK_KP7] ){ key_speed_x -= 2.0 + abs(key_speed_x)*0.4; key_speed_y -= 2.0 + abs(key_speed_y)*0.4; }
-		if( keystate[SDLK_KP9] ){ key_speed_x += 2.0 + abs(key_speed_x)*0.4; key_speed_y -= 2.0 + abs(key_speed_y)*0.4; }
-		if( keystate[SDLK_KP3] ){ key_speed_x += 2.0 + abs(key_speed_x)*0.4; key_speed_y += 2.0 + abs(key_speed_y)*0.4; }
-		if( keystate[SDLK_KP1] ){ key_speed_x -= 2.0 + abs(key_speed_x)*0.4; key_speed_y += 2.0 + abs(key_speed_y)*0.4; }
+		if( keystate[LEFT]  || keystate[KP4] ) key_speed_x -= 2.0 + abs(key_speed_x)*0.4;
+		if( keystate[RIGHT] || keystate[KP6] ) key_speed_x += 2.0 + abs(key_speed_x)*0.4;
+		if( keystate[UP]    || keystate[KP8] ) key_speed_y -= 2.0 + abs(key_speed_y)*0.4;
+		if( keystate[DOWN]  || keystate[KP2] ) key_speed_y += 2.0 + abs(key_speed_y)*0.4;
+		if( keystate[KP7] ){ key_speed_x -= 2.0 + abs(key_speed_x)*0.4; key_speed_y -= 2.0 + abs(key_speed_y)*0.4; }
+		if( keystate[KP9] ){ key_speed_x += 2.0 + abs(key_speed_x)*0.4; key_speed_y -= 2.0 + abs(key_speed_y)*0.4; }
+		if( keystate[KP3] ){ key_speed_x += 2.0 + abs(key_speed_x)*0.4; key_speed_y += 2.0 + abs(key_speed_y)*0.4; }
+		if( keystate[KP1] ){ key_speed_x -= 2.0 + abs(key_speed_x)*0.4; key_speed_y += 2.0 + abs(key_speed_y)*0.4; }
 		//float s = (1.0-game->speedAdj)+(game->speedAdj*0.7);
 		float s = 0.7;
 		key_speed_x *= s;
@@ -456,7 +554,11 @@ void MainSDL::mouseMotion(SDL_Event *event)
 			if(xDiff || yDiff)
 			{
 				game->hero->moveEvent(xDiff, yDiff);
+#if SDL_VERSION_ATLEAST(2,0,0)
+				SDL_WarpMouseInWindow(window, xMid, yMid);
+#else
 				SDL_WarpMouse(xMid, yMid);
+#endif
 			}
 		}
 		xLast = xNow;
@@ -491,7 +593,7 @@ void MainSDL::mouseButtonDown(SDL_Event *ev)
 	{
 		game->menu->keyHit(MainToolkit::KeyEnter);
 	}
-	
+
 }
 
 //----------------------------------------------------------
@@ -536,7 +638,7 @@ void MainSDL::grabMouse(bool status, bool warpmouse)
 {
 	Config *config = Config::instance();
 	if( config->debug() ) fprintf(stderr, _("MainSDL::grabMouse(%d)\n"), status);
-	
+
 	mouseToggle = status;
 	if(status)
 		SDL_ShowCursor(0);
@@ -546,7 +648,11 @@ void MainSDL::grabMouse(bool status, bool warpmouse)
 		return;
 	xMid = config->screenW()/2;
 	yMid = config->screenH()/2;
+#if SDL_VERSION_ATLEAST(2,0,0)
+	SDL_WarpMouseInWindow(window, xMid, yMid);
+#else
 	SDL_WarpMouse(xMid, yMid);
+#endif
 	xLast = xMid;
 	yLast = yMid;
 }
