@@ -1,8 +1,8 @@
 /*
  * Copyright (c) 2000 Mark B. Allan. All rights reserved.
  *
- * "Chromium B.S.U." is free software; you can redistribute 
- * it and/or use it and/or modify it under the terms of the 
+ * "Chromium B.S.U." is free software; you can redistribute
+ * it and/or use it and/or modify it under the terms of the
  * "Clarified Artistic License"
  */
 
@@ -69,7 +69,7 @@ int main(int argc, char **argv)
 	// set however, use default value.
 	setenv("SDL_VIDEO_X11_DGAMOUSE", "0", false);
 #endif
-	
+
 	Config	*config	= Config::init();
 	Global	*game	= Global::init();
 	HiScore	*hiScore = HiScore::init();
@@ -113,6 +113,11 @@ int main(int argc, char **argv)
 		{
 			config->setDebug(true);
 		}
+		else if( strcmp(argv[i], "-V") == 0 || strcmp(argv[i], "--version") == 0)
+		{
+			printf("%s\n", PACKAGE_STRING);
+			exit(0);
+		}
 		else
 		{
 			fprintf(stderr, _(
@@ -130,17 +135,18 @@ int main(int argc, char **argv)
 				"  -na/--noaudio        : do not initialize audio\n"
 				"  -nb/--noblend        : disable blending (OpenGL)\n"
 				"  -nt/--notexborder    : do not set tex border color (OpenGL)\n"
+				"  -V/--version         : show version information\n"
 				"--------------------------------------------------\n\n"));
 			exit(0);
 		}
 	}
-	
+
 	if( config->debug() ) atexit(EnemyAircraft::printNumAllocated);
 
 	srand(time(NULL));
-	
+
 	game->generateRandom();
-	
+
 #ifdef USE_SDL
 	game->toolkit = new MainSDL(argc, argv);
 #elif USE_GLUT
@@ -148,7 +154,7 @@ int main(int argc, char **argv)
 #else
 #error "USE_SDL or USE_GLUT must be defined"
 #endif
-		
+
 	if( config->debug() ) hiScore->print(config->intSkill());
 	game->toolkit->run();
 
@@ -198,7 +204,7 @@ const char* dataLoc(const char* filename, bool doCheck)
 
 	if(getenv("HOME") != NULL && ((strlen(getenv("HOME"))+strlen(filename)) < 239) )
 	{
-		sprintf(buffer, "%s/."PACKAGE"-data/%s", getenv("HOME"), filename);
+		sprintf(buffer, "%s/." PACKAGE "-data/%s", getenv("HOME"), filename);
 		if(stat(buffer, &sbuf) == 0) return buffer;
 	}
 
@@ -226,7 +232,7 @@ const char* dataLoc(const char* filename, bool doCheck)
 #ifndef _WIN32 // WIN32 users don't get error checks...
 	if(doCheck)
 	{
-		if(stat(buffer, &sbuf) == -1) 
+		if(stat(buffer, &sbuf) == -1)
 		{
 			fprintf(stderr, _("!! ERROR !! - "));
 			perror(buffer);
@@ -251,7 +257,7 @@ void printExtensions(FILE *fstream, const char* extstr_in)
 	extstr = new char[len+1];
 	strcpy(extstr, extstr_in);
 	walker = extstr;
-	
+
 	fprintf(fstream, _("Extensions :"));
 	while( (walker-extstr) < len )
 	{
@@ -269,6 +275,6 @@ void printExtensions(FILE *fstream, const char* extstr_in)
 			break;
 	}
 	fprintf(fstream, "\n");
-	
+
 	delete [] extstr;
 }
